@@ -41,15 +41,15 @@ header file for Sablot.cpp
 
 
 /* version info */
-#define SAB_VERSION "0.98"
-#define SAB_DATE "April 7, 2003"
+#define SAB_VERSION "1.0.1"
+#define SAB_DATE "November 24, 2003"
 
 /* common types */
 typedef void *SablotHandle;
 typedef void *SDOM_Document;
 typedef void *SablotSituation;
 
-#if defined(WIN32) && defined(_MSC_VER)
+#if defined(WIN32) && defined(_MSC_VER) && !defined(SABLOT_STATIC)
 #if defined(SablotAsExport)
 #define DllImpExp __declspec( dllexport )
 #else
@@ -79,7 +79,9 @@ typedef enum
   SAB_DISABLE_ADDING_META   =  0x4,
   SAB_DISABLE_STRIPPING     =  0x8,
   SAB_IGNORE_DOC_NOT_FOUND  = 0x10,
-  SAB_FILES_TO_HANDLER      = 0x20
+  SAB_FILES_TO_HANDLER      = 0x20,
+  SAB_DUMP_SHEET_STRUCTURE  = 0x40,
+  SAB_NO_EXTERNAL_ENTITIES  = 0x80
 }  SablotFlag;
 
 /* create a new document */
@@ -562,5 +564,4 @@ Declare
     void SablotSetEncoding(SablotHandle processor_, char *encoding_);
 )
 
-#endif /* defined SablotHIncl */
-
+#endif
